@@ -17,6 +17,7 @@
 //! ```rust
 //! use gamie::tictactoe::*;
 //!
+//! # fn tictactoe() {
 //! let mut game = TicTacToe::new();
 //! game.place(TicTacToePlayer::X, 1, 1).unwrap();
 //! game.place(TicTacToePlayer::O, 0, 0).unwrap();
@@ -29,13 +30,19 @@
 //! game.place(TicTacToePlayer::X, 2, 2).unwrap();
 //! assert!(game.is_ended());
 //! assert_eq!(game.status(), TicTacToeStatus::Tie);
+//! # }
 //! ```
 //!
 //! Check the [docs](https://docs.rs/gamie) for further usage information.
 //!
 //! ## Modules
 //! Currently, the following modules are available:
-//! - tictactoe: The Tic-Tac-Toe game.
+//!
+//! - (WIP) reversi: Reversi (Othello) game
+//! - tictactoe: The classic Tic-Tac-Toe game
+
+#[cfg(feature = "reversi")]
+pub mod reversi;
 
 #[cfg(feature = "tictactoe")]
 pub mod tictactoe;
